@@ -1,20 +1,7 @@
 /*
- *   Copyright (C) 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *   SPDX-FileCopyrightText: 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library/Lesser General Public License
- *   version 2, or (at your option) any later version, as published by the
- *   Free Software Foundation
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library/Lesser General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+ *   SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "DiscoverObject.h"
@@ -41,7 +28,7 @@
 #include <QSessionManager>
 #include <QClipboard>
 #include <QDBusConnection>
-#include <QDBusInterface>
+#include <QDBusMessage>
 #include <QDBusPendingCall>
 
 // KDE includes
@@ -55,7 +42,9 @@
 #include <KSharedConfig>
 #include <KConfigGroup>
 #include <KStandardAction>
+#include <KCrash>
 #include <kcoreaddons_version.h>
+#include <kcrash_version.h>
 // #include <KSwitchLanguageDialog>
 
 // DiscoverCommon includes
@@ -351,6 +340,12 @@ void DiscoverObject::integrateObject(QObject* object)
         QWindow::Visibility visibility(QWindow::Visibility(window.readEntry<int>("visibility", QWindow::Windowed)));
         rootObject()->setVisibility(qMax(visibility, QQuickView::AutomaticVisibility));
     }
+    connect(rootObject(), &QQuickView::sceneGraphError, this, [] (QQuickWindow::SceneGraphError /*error*/, const QString &message) {
+#if KCrash_VERSION >= QT_VERSION_CHECK(5, 69, 0)
+        KCrash::setErrorMessage(message);
+#endif
+        qFatal("%s", qPrintable(message));
+    });
 
     object->installEventFilter(this);
     connect(object, &QObject::destroyed, qGuiApp, &QCoreApplication::quit);
@@ -496,9 +491,9 @@ void DiscoverObject::loadTest(const QUrl& url)
     new DiscoverTestExecutor(rootObject(), engine(), url);
 }
 
-QWindow* DiscoverObject::rootObject() const
+QQuickWindow* DiscoverObject::rootObject() const
 {
-    return qobject_cast<QWindow*>(m_engine->rootObjects().at(0));
+    return qobject_cast<QQuickWindow*>(m_engine->rootObjects().at(0));
 }
 
 void DiscoverObject::showPassiveNotification(const QString& msg)
@@ -510,8 +505,12 @@ void DiscoverObject::showPassiveNotification(const QString& msg)
 
 void DiscoverObject::reboot()
 {
-    QDBusInterface interface(QStringLiteral("org.kde.ksmserver"), QStringLiteral("/KSMServer"), QStringLiteral("org.kde.KSMServerInterface"), QDBusConnection::sessionBus());
-    interface.asyncCall(QStringLiteral("logout"), 1, 1, 2); // Options: confirm first | reboot | force
+    QDBusConnection::sessionBus().asyncCall(
+        QDBusMessage::createMethodCall(QStringLiteral("org.kde.LogoutPrompt"),
+                                       QStringLiteral("/LogoutPrompt"),
+                                       QStringLiteral("org.kde.LogoutPrompt"),
+                                       QStringLiteral("promptReboot"))
+    );
 }
 
 QRect DiscoverObject::initialGeometry() const
