@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright © 2016 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2016 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 #include "FeaturedModel.h"
 
@@ -26,6 +12,7 @@
 #include <QJsonDocument>
 #include <QJsonArray>
 #include <QDir>
+#include <QtGlobal>
 #include <KIO/StoredTransferJob>
 
 #include <utils.h>
@@ -36,10 +23,7 @@ Q_GLOBAL_STATIC(QString, featuredCache)
 
 FeaturedModel::FeaturedModel()
 {
-    connect(ResourcesModel::global(), &ResourcesModel::backendsChanged, this, &FeaturedModel::refresh);
-    connect(ResourcesModel::global(), &ResourcesModel::currentApplicationBackendChanged, this, &FeaturedModel::refresh);
-    connect(ResourcesModel::global(), &ResourcesModel::fetchingChanged, this, &FeaturedModel::refresh);
-    connect(ResourcesModel::global(), &ResourcesModel::resourceRemoved, this, &FeaturedModel::removeResource);
+    connect(ResourcesModel::global(), &ResourcesModel::currentApplicationBackendChanged, this, &FeaturedModel::refreshCurrentApplicationBackend);
 
     const QString dir = QStandardPaths::writableLocation(QStandardPaths::CacheLocation);
     QDir().mkpath(dir);
@@ -51,25 +35,51 @@ FeaturedModel::FeaturedModel()
     auto *fetchJob = KIO::storedGet(featuredUrl, KIO::NoReload, KIO::HideProgressInfo);
     acquireFetching(true);
     connect(fetchJob, &KIO::StoredTransferJob::result, this, [this, fetchJob]() {
-        const auto dest = qScopeGuard([this] { acquireFetching(false); });
-        if (fetchJob->error() != 0) {
+        const auto dest = qScopeGuard([this] {
+            acquireFetching(false);
             refresh();
+        });
+        if (fetchJob->error() != 0)
             return;
-        }
+
         QFile f(*featuredCache);
         if (!f.open(QIODevice::WriteOnly))
             qCWarning(DISCOVER_LOG) << "could not open" << *featuredCache << f.errorString();
         f.write(fetchJob->data());
         f.close();
-        refresh();
     });
 
-    if (!ResourcesModel::global()->backends().isEmpty() && QFile::exists(*featuredCache))
+    refreshCurrentApplicationBackend();
+}
+
+void FeaturedModel::refreshCurrentApplicationBackend()
+{
+    auto backend = ResourcesModel::global()->currentApplicationBackend();
+    if (m_backend == backend)
+        return;
+
+    if (m_backend) {
+        disconnect(m_backend, &AbstractResourcesBackend::fetchingChanged, this, &FeaturedModel::refresh);
+        disconnect(m_backend, &AbstractResourcesBackend::resourceRemoved, this, &FeaturedModel::removeResource);
+    }
+
+    m_backend = backend;
+
+    if (backend) {
+        connect(backend, &AbstractResourcesBackend::fetchingChanged, this, &FeaturedModel::refresh);
+        connect(backend, &AbstractResourcesBackend::resourceRemoved, this, &FeaturedModel::removeResource);
+    }
+
+    if (backend && QFile::exists(*featuredCache))
         refresh();
 }
 
 void FeaturedModel::refresh()
 {
+    //usually only useful if launching just fwupd or kns backends
+    if (!m_backend)
+        return;
+
     acquireFetching(true);
     const auto dest = qScopeGuard([this] { acquireFetching(false); });
     QFile f(*featuredCache);
@@ -90,15 +100,14 @@ void FeaturedModel::refresh()
 
 void FeaturedModel::setUris(const QVector<QUrl>& uris)
 {
-    auto backend = ResourcesModel::global()->currentApplicationBackend();
-    if (!backend)
+    if (!m_backend)
         return;
 
     QSet<ResultsStream*> streams;
     foreach(const auto &uri, uris) {
         AbstractResourcesBackend::Filters filter;
         filter.resourceUrl = uri;
-        streams << backend->search(filter);
+        streams << m_backend->search(filter);
     }
     if (!streams.isEmpty()) {
         auto stream = new StoredResultsStream(streams);
@@ -109,16 +118,13 @@ void FeaturedModel::setUris(const QVector<QUrl>& uris)
 
 static void filterDupes(QVector<AbstractResource *> &resources)
 {
-    const auto appsBackend = ResourcesModel::global()->currentApplicationBackend();
-    QHash<QString, AbstractResource*> resById;
+    QSet<QString> found;
     for(auto it = resources.begin(); it!=resources.end(); ) {
         auto id = (*it)->appstreamId();
-        auto curr = resById.value(id);
-        if (curr && curr->backend() == appsBackend) {
+        if (found.contains(id)) {
             it = resources.erase(it);
         } else {
-            resources.removeAll(curr);
-            resById[id] = *it;
+            found.insert(id);
             ++it;
         }
     }
