@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright © 2014 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2014 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 #include "DummySourcesBackend.h"
 #include <QDebug>
@@ -67,14 +53,28 @@ bool DummySourcesBackend::removeSource(const QString& id)
 {
     const auto it = sourceForId(id);
     if (!it) {
-        qWarning() << "couldn't find " << id;
+        Q_EMIT passiveMessage(QStringLiteral("Could not find %1").arg(id));
         return false;
     }
     return m_sources->removeRow(it->row());
 }
 
-QList<QAction*> DummySourcesBackend::actions() const
+QVariantList DummySourcesBackend::actions() const
 {
-    return QList<QAction*>() << m_testAction;
+    return QVariantList() << QVariant::fromValue<QObject*>(m_testAction);
 }
 
+bool DummySourcesBackend::moveSource(const QString& sourceId, int delta)
+{
+    int row = sourceForId(sourceId)->row();
+    auto prevRow = m_sources->takeRow(row);
+    Q_ASSERT(!prevRow.isEmpty());
+
+    const auto destRow = row + delta;
+    m_sources->insertRow(destRow, prevRow);
+    if (destRow == 0 || row == 0)
+        Q_EMIT firstSourceIdChanged();
+    if (destRow == m_sources->rowCount() - 1 || row == m_sources->rowCount() - 1)
+        Q_EMIT lastSourceIdChanged();
+    return true;
+}
