@@ -1,23 +1,10 @@
-/***************************************************************************
- *   Copyright © 2014 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
- *   Copyright © 2017 Jan Grulich <jgrulich@redhat.com>                    *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2014 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *   SPDX-FileCopyrightText: 2017 Jan Grulich <jgrulich@redhat.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
+
 
 #include "FlatpakSourcesBackend.h"
 #include "FlatpakResource.h"
@@ -95,24 +82,22 @@ bool FlatpakSourcesBackend::addSource(const QString &id)
     if (id.isEmpty() || !flatpakrepoUrl.isValid())
         return false;
 
-    if (flatpakrepoUrl.isLocalFile()) {
-        auto res = backend->addSourceFromFlatpakRepo(flatpakrepoUrl);
+    auto addSource = [=](AbstractResource* res) {
         if (res)
             backend->installApplication(res);
         else
-            backend->passiveMessage(i18n("Could not add the source %1", flatpakrepoUrl.toDisplayString()));
+            Q_EMIT backend->passiveMessage(i18n("Could not add the source %1", flatpakrepoUrl.toDisplayString()));
+    };
+
+    if (flatpakrepoUrl.isLocalFile()) {
+        addSource(backend->addSourceFromFlatpakRepo(flatpakrepoUrl));
     } else {
         AbstractResourcesBackend::Filters filter;
         filter.resourceUrl = flatpakrepoUrl;
         auto stream = new StoredResultsStream ({backend->search(filter)});
-        connect(stream, &StoredResultsStream::finished, this, [backend, stream, flatpakrepoUrl]() {
+        connect(stream, &StoredResultsStream::finished, this, [addSource, stream]() {
             const auto res = stream->resources();
-            if (!res.isEmpty()) {
-                Q_ASSERT(res.count() == 1);
-                backend->installApplication(res.first());
-            } else {
-                backend->passiveMessage(i18n("Could not add the source %1", flatpakrepoUrl.toDisplayString()));
-            }
+            addSource(res.value(0));
         });
     }
     return true;
@@ -131,6 +116,21 @@ QStandardItem * FlatpakSourcesBackend::sourceById(const QString& id) const
     return sourceIt;
 }
 
+QStandardItem * FlatpakSourcesBackend::sourceByUrl(const QString& _url) const
+{
+    QUrl url(_url);
+
+    QStandardItem* sourceIt = nullptr;
+    for (int i = 0, c = m_sources->rowCount(); i<c && !sourceIt; ++i) {
+        auto it = m_sources->item(i);
+        if (url.matches(it->data(Qt::StatusTipRole).toUrl(), QUrl::StripTrailingSlash)) {
+            sourceIt = it;
+            break;
+        }
+    }
+    return sourceIt;
+}
+
 bool FlatpakSourcesBackend::removeSource(const QString &id)
 {
     auto sourceIt = sourceById(id);
@@ -138,7 +138,69 @@ bool FlatpakSourcesBackend::removeSource(const QString &id)
         FlatpakSourceItem *sourceItem = static_cast<FlatpakSourceItem*>(sourceIt);
         g_autoptr(GCancellable) cancellable = g_cancellable_new();
         g_autoptr(GError) error = nullptr;
-        if (flatpak_installation_remove_remote(sourceItem->flatpakInstallation(), id.toUtf8().constData(), cancellable, &error)) {
+        const auto installation = sourceItem->flatpakInstallation();
+
+        g_autoptr(GPtrArray) refs = flatpak_installation_list_remote_refs_sync(installation, id.toUtf8().constData(), cancellable, &error);
+        if (refs) {
+            QHash<QString, QStringList> toRemoveHash;
+            toRemoveHash.reserve(refs->len);
+            QStringList toRemoveRefs;
+            toRemoveRefs.reserve(refs->len);
+            FlatpakBackend* backend = qobject_cast<FlatpakBackend*>(parent());
+            for (uint i = 0; i < refs->len; i++) {
+                FlatpakRef *ref= FLATPAK_REF(g_ptr_array_index(refs, i));
+
+                g_autoptr(GError) error = nullptr;
+                FlatpakInstalledRef* installedRef = flatpak_installation_get_installed_ref(installation, flatpak_ref_get_kind(ref), flatpak_ref_get_name(ref), flatpak_ref_get_arch(ref), flatpak_ref_get_branch(ref), cancellable, &error);
+                if (installedRef) {
+                    auto res = backend->getAppForInstalledRef(installation, installedRef);
+                    const auto name = QString::fromUtf8(flatpak_ref_get_name(ref));
+                    const auto refString = QString::fromUtf8(flatpak_ref_format_ref(ref));
+                    if (!name.endsWith(QLatin1String(".Locale"))) {
+                        if (res)
+                            toRemoveHash[res->name()] << refString;
+                        else
+                            toRemoveHash[refString] << refString;
+                    }
+                    toRemoveRefs << refString;
+                }
+            }
+            QStringList toRemove;
+            toRemove.reserve(toRemoveHash.count());
+            for (auto it = toRemoveHash.constBegin(), itEnd = toRemoveHash.constEnd(); it != itEnd; ++it) {
+                if (it.value().count() > 1)
+                    toRemove << QStringLiteral("%1 - %2").arg(it.key(), it.value().join(QLatin1String(", ")));
+                else
+                    toRemove << it.key();
+            }
+            toRemove.sort();
+
+            if (!toRemove.isEmpty()) {
+                m_proceedFunctions.push([this, toRemoveRefs, installation, id] {
+                    g_autoptr(GError) localError = nullptr;
+                    g_autoptr(GCancellable) cancellable = g_cancellable_new();
+                    g_autoptr(FlatpakTransaction) transaction = flatpak_transaction_new_for_installation(installation, cancellable, &localError);
+                    for (const QString& instRef : qAsConst(toRemoveRefs)) {
+                        const QByteArray refString = instRef.toUtf8();
+                        flatpak_transaction_add_uninstall(transaction, refString.constData(), &localError);
+                        if (localError)
+                            return;
+                    }
+
+                    if (flatpak_transaction_run(transaction, cancellable, &localError)) {
+                        removeSource(id);
+                    }
+                });
+
+
+                Q_EMIT proceedRequest(i18n("Removing '%1'", id), i18n("To remove this repository, the following applications must be uninstalled:<ul><li>%1</li></ul>", toRemove.join(QStringLiteral("</li><li>"))));
+                return false;
+            }
+        } else {
+            qWarning() << "could not list refs in repo" << id << error->message;
+        }
+
+        if (flatpak_installation_remove_remote(installation, id.toUtf8().constData(), cancellable, &error)) {
             m_sources->removeRow(sourceItem->row());
 
             if (m_sources->rowCount() == 0) {
@@ -146,20 +208,20 @@ bool FlatpakSourcesBackend::removeSource(const QString &id)
             }
             return true;
         } else {
-            qWarning() << "Failed to remove " << id << " remote repository:" << error->message;
+            Q_EMIT passiveMessage(i18n("Failed to remove %1 remote repository: %2", id, QString::fromUtf8(error->message)));
             return false;
         }
     } else {
-        qWarning() << "couldn't find " << id;
+        Q_EMIT passiveMessage(i18n("Could not find %1", id));
         return false;
     }
 
     return false;
 }
 
-QList<QAction*> FlatpakSourcesBackend::actions() const
+QVariantList FlatpakSourcesBackend::actions() const
 {
-    return { m_flathubAction };
+    return { QVariant::fromValue<QObject*>(m_flathubAction) };
 }
 
 bool FlatpakSourcesBackend::listRepositories(FlatpakInstallation* installation)
@@ -192,7 +254,7 @@ FlatpakRemote * FlatpakSourcesBackend::installSource(FlatpakResource *resource)
 
     auto remote = flatpak_installation_get_remote_by_name(m_preferredInstallation, resource->flatpakName().toUtf8().constData(), cancellable, nullptr);
     if (remote) {
-        qWarning() << "Source " << resource->flatpakName() << " already exists";
+        qWarning() << "Source " << resource->flatpakName() << " already exists in" << flatpak_installation_get_path(m_preferredInstallation);
         return nullptr;
     }
 
@@ -234,7 +296,9 @@ void FlatpakSourcesBackend::addRemote(FlatpakRemote *remote, FlatpakInstallation
     const QString title = QString::fromUtf8(flatpak_remote_get_title(remote));
     const QUrl remoteUrl(QString::fromUtf8(flatpak_remote_get_url(remote)));
 
-    for(QAction *action: actions()) {
+    const auto theActions = actions();
+    for(const QVariant& act: theActions) {
+        QAction* action = qobject_cast<QAction*>(act.value<QObject*>());
         if (action->toolTip() == id) {
             action->setEnabled(false);
             action->setVisible(false);
@@ -242,9 +306,12 @@ void FlatpakSourcesBackend::addRemote(FlatpakRemote *remote, FlatpakInstallation
     }
 
     FlatpakSourceItem *it = new FlatpakSourceItem(!title.isEmpty() ? title : id);
-    it->setCheckState(flatpak_remote_get_disabled(remote) ? Qt::Unchecked : Qt::Checked);
     it->setData(remoteUrl.isLocalFile() ? remoteUrl.toLocalFile() : remoteUrl.host(), Qt::ToolTipRole);
+    it->setData(remoteUrl, Qt::StatusTipRole);
     it->setData(id, IdRole);
+#if FLATPAK_CHECK_VERSION(1,4,0)
+    it->setData(QString::fromUtf8(flatpak_remote_get_icon(remote)), IconUrlRole);
+#endif
     it->setFlatpakInstallation(installation);
 
     int idx = -1;
@@ -280,7 +347,7 @@ void FlatpakSourcesBackend::addRemote(FlatpakRemote *remote, FlatpakInstallation
 
 QString FlatpakSourcesBackend::idDescription()
 {
-    return i18n("Flatpak repository URI (*.flatpakrepo)");
+    return i18n("Enter a Flatpak repository URI (*.flatpakrepo):");
 }
 
 bool FlatpakSourcesBackend::moveSource(const QString& sourceId, int delta)
@@ -306,3 +373,13 @@ int FlatpakSourcesBackend::originIndex(const QString& sourceId) const
     auto item = sourceById(sourceId);
     return item ? item->row() : INT_MAX;
 }
+
+void FlatpakSourcesBackend::cancel()
+{
+    m_proceedFunctions.pop();
+}
+
+void FlatpakSourcesBackend::proceed()
+{
+    m_proceedFunctions.pop()();
+}
