@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright © 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 #ifndef KNSRESOURCE_H
 #define KNSRESOURCE_H
@@ -43,7 +29,7 @@ public:
     QString packageName() const override;
     QStringList categories() override;
     QUrl homepage() override;
-    QString license() override;
+    QJsonArray licenses() override;
     QString longDescription() override;
     QList<PackageState> addonsInformation() override { return QList<PackageState>(); }
     QString availableVersion() const override;
@@ -54,6 +40,8 @@ public:
     int size() override;
     void fetchChangelog() override;
     QStringList extends() const override;
+    AbstractResource::Type type() const override { return Addon; }
+    QString author() const override;
 
     KNSBackend* knsBackend() const;
 
