@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright © 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 #include "KNSReviews.h"
 #include "KNSBackend.h"
@@ -67,34 +53,40 @@ Rating* KNSReviews::ratingForApplication(AbstractResource* app) const
 void KNSReviews::fetchReviews(AbstractResource* app, int page)
 {
     Attica::ListJob< Attica::Comment >* job =
-        provider().requestComments(Attica::Comment::ContentComment, app->packageName(), QStringLiteral("0"), page, 10);
+        provider().requestComments(Attica::Comment::ContentComment, app->packageName(), QStringLiteral("0"), page - 1, 10);
     if (!job) {
         emit reviewsReady(app, {}, false);
         return;
     }
-    job->setProperty("app", qVariantFromValue<AbstractResource*>(app));
+    job->setProperty("app", QVariant::fromValue<AbstractResource*>(app));
     connect(job, &Attica::BaseJob::finished, this, &KNSReviews::commentsReceived);
     job->start();
     m_fetching++;
 }
 
+static QVector<ReviewPtr> createReviewList(AbstractResource* app, Attica::Comment::List comments, int depth = 0) {
+    QVector<ReviewPtr> reviews;
+    foreach(const Attica::Comment& comment, comments) {
+        //TODO: language lookup?
+        ReviewPtr r(new Review(app->name(), app->packageName(), QStringLiteral("en"), comment.subject(), comment.text(), comment.user(),
+            comment.date(), true, comment.id().toInt(), comment.score()/10, 0, 0, QString()
+        ));
+        r->addMetadata(QStringLiteral("NumberOfParents"), depth);
+        reviews += r;
+        if (comment.childCount() > 0) {
+            reviews += createReviewList(app, comment.children(), depth + 1);
+        }
+    }
+    return reviews;
+}
+
 void KNSReviews::commentsReceived(Attica::BaseJob* j)
 {
     m_fetching--;
     Attica::ListJob<Attica::Comment>* job = static_cast<Attica::ListJob<Attica::Comment>*>(j);
-    Attica::Comment::List comments = job->itemList();
 
-    QVector<ReviewPtr> reviews;
-    reviews.reserve(comments.count());
     AbstractResource* app = job->property("app").value<AbstractResource*>();
-    foreach(const Attica::Comment& comment, comments) {
-        //TODO: language lookup?
-        const QString subject = comment.subject().isEmpty() ? QStringLiteral(".") : comment.subject();
-        ReviewPtr r(new Review(app->name(), app->packageName(), QStringLiteral("en"), subject, comment.text(), comment.user(),
-            comment.date(), true, comment.id().toInt(), comment.score()/10, 0, 0, QString()
-        ));
-        reviews += r;
-    }
+    QVector<ReviewPtr> reviews = createReviewList(app, job->itemList());
 
     emit reviewsReady(app, reviews, !reviews.isEmpty());
 }
