@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright © 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 #ifndef PACKAGEKITBACKEND_H
 #define PACKAGEKITBACKEND_H
@@ -29,13 +15,16 @@
 #include <QTimer>
 #include <QSet>
 #include <QSharedPointer>
+#include <QThreadPool>
 #include <PackageKit/Transaction>
 #include <AppStreamQt/pool.h>
 
 class AppPackageKitResource;
 class PackageKitUpdater;
-class PKTransaction;
 class OdrsReviewsBackend;
+class PKResultsStream;
+class PKResolveTransaction;
+
 class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
 {
     Q_OBJECT
@@ -48,7 +37,7 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         QSet<AbstractResource*> resourcesByPackageName(const QString& name) const;
 
         ResultsStream* search(const AbstractResourcesBackend::Filters & search) override;
-        ResultsStream* findResourceByPackageName(const QUrl& search);
+        PKResultsStream* findResourceByPackageName(const QUrl& search);
         int updatesCount() const override;
         bool hasSecurityUpdates() const override;
 
@@ -63,11 +52,10 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         QString upgradeablePackageId(const PackageKitResource* res) const;
         QVector<AppPackageKitResource*> extendedBy(const QString& id) const;
 
-        void clearPackages(const QStringList &packageNames);
         void resolvePackages(const QStringList &packageNames);
-        void fetchDetails(const QString& pkgid);
+        void fetchDetails(const QString& pkgid) { fetchDetails(QSet<QString>{pkgid}); }
+        void fetchDetails(const QSet<QString>& pkgid);
 
-        AbstractResource * resourceForFile(const QUrl & ) override;
         void checkForUpdates() override;
         QString displayName() const override;
 
@@ -75,6 +63,11 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         static QString locateService(const QString &filename);
 
         QList<AppStream::Component> componentsById(const QString &id) const;
+        void fetchUpdates();
+        int fetchingUpdatesProgress() const override;
+
+        void addPackageArch(PackageKit::Transaction::Info info, const QString &packageId, const QString &summary);
+        void addPackageNotArch(PackageKit::Transaction::Info info, const QString &packageId, const QString &summary);
 
     public Q_SLOTS:
         void reloadPackageList();
@@ -83,23 +76,27 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
     private Q_SLOTS:
         void getPackagesFinished();
         void addPackage(PackageKit::Transaction::Info info, const QString &packageId, const QString &summary, bool arch);
-        void addPackageArch(PackageKit::Transaction::Info info, const QString &packageId, const QString &summary);
-        void addPackageNotArch(PackageKit::Transaction::Info info, const QString &packageId, const QString &summary);
         void packageDetails(const PackageKit::Details& details);
         void addPackageToUpdate(PackageKit::Transaction::Info, const QString& pkgid, const QString& summary);
         void getUpdatesFinished(PackageKit::Transaction::Exit,uint);
-        void getUpdatesDetailsFinished(PackageKit::Transaction::Exit,uint);
+
+    Q_SIGNALS:
+        void loadedAppStream();
+        void available();
 
     private:
+        friend class PackageKitResource;
         template <typename T>
         T resourcesByPackageNames(const QStringList& names) const;
-        void fetchUpdates();
+
+        void runWhenInitialized(const std::function<void()> &f, QObject* stream);
 
         void checkDaemonRunning();
         void acquireFetching(bool f);
         void includePackagesToAdd();
         void performDetailsFetch();
         AppPackageKitResource* addComponent(const AppStream::Component& component, const QStringList& pkgNames);
+        void updateProxy();
 
         QScopedPointer<AppStream::Pool> m_appdata;
         PackageKitUpdater* m_updater;
@@ -109,18 +106,20 @@ class DISCOVERCOMMON_EXPORT PackageKitBackend : public AbstractResourcesBackend
         bool m_hasSecurityUpdates = false;
         QSet<PackageKitResource*> m_packagesToAdd;
         QSet<PackageKitResource*> m_packagesToDelete;
+        bool m_appstreamInitialized = false;
 
-        struct Packages {
+        struct {
             QHash<QString, AbstractResource*> packages;
             QHash<QString, QStringList> packageToApp;
             QHash<QString, QVector<AppPackageKitResource*>> extendedBy;
-            void clear() { *this = {}; }
-        };
+        } m_packages;
 
         QTimer m_delayedDetailsFetch;
         QSet<QString> m_packageNamesToFetchDetails;
-        Packages m_packages;
         QSharedPointer<OdrsReviewsBackend> m_reviews;
+        QPointer<PackageKit::Transaction> m_getUpdatesTransaction;
+        QThreadPool m_threadPool;
+        QPointer<PKResolveTransaction> m_resolveTransaction;
 };
 
 #endif // PACKAGEKITBACKEND_H
