@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright © 2016 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2016 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 #include "PackageKitSourcesBackend.h"
 #include <QStandardItemModel>
@@ -27,6 +13,8 @@
 #include <QAction>
 #include <QProcess>
 #include <QDebug>
+#include <QRegularExpression>
+#include <resources/SourcesModel.h>
 #include <resources/AbstractResourcesBackend.h>
 #include "PackageKitBackend.h"
 #include "config-paths.h"
@@ -38,13 +26,6 @@ public:
         : QStandardItemModel(backend)
         , m_backend(backend) {}
 
-    QHash<int, QByteArray> roleNames() const override
-    {
-        auto roles = QStandardItemModel::roleNames();
-        roles[Qt::CheckStateRole] = "checked";
-        return roles;
-    }
-
     bool setData(const QModelIndex & index, const QVariant & value, int role) override {
         auto item = itemFromIndex(index);
         if (!item)
@@ -71,6 +52,7 @@ static QAction* createActionForService(const QString &servicePath, QObject* pare
     KDesktopFile parser(servicePath);
     action->setIcon(QIcon::fromTheme(parser.readIcon()));
     action->setText(parser.readName());
+    action->setToolTip(parser.readComment());
     QObject::connect(action, &QAction::triggered, action, [servicePath](){
         bool b = QProcess::startDetached(QStringLiteral(CMAKE_INSTALL_FULL_LIBEXECDIR_KF5 "/discover/runservice"), {servicePath});
         if (!b)
@@ -84,17 +66,23 @@ PackageKitSourcesBackend::PackageKitSourcesBackend(AbstractResourcesBackend* par
     , m_sources(new PKSourcesModel(this))
 {
     connect(PackageKit::Daemon::global(), &PackageKit::Daemon::repoListChanged, this, &PackageKitSourcesBackend::resetSources);
-    resetSources();
+    connect(SourcesModel::global(), &SourcesModel::showingNow, this, &PackageKitSourcesBackend::resetSources);
 
     // Kubuntu-based
-    auto service = PackageKitBackend::locateService(QStringLiteral("software-properties-kde.desktop"));
-    if (!service.isEmpty())
-        m_actions += createActionForService(service, this);
+    auto addNativeSourcesManager = [this](const QString &file){
+        auto service = PackageKitBackend::locateService(file);
+        if (!service.isEmpty())
+            m_actions += QVariant::fromValue<QObject*>(createActionForService(service, this));
+        };
 
-    // openSUSE-based
-    service = PackageKitBackend::locateService(QStringLiteral("YaST2/sw_source.desktop"));
-    if (!service.isEmpty())
-        m_actions += createActionForService(service, this);
+    //New Ubuntu
+    addNativeSourcesManager(QStringLiteral("software-properties-qt.desktop"));
+
+    //Old Ubuntu
+    addNativeSourcesManager(QStringLiteral("software-properties-kde.desktop"));
+
+    //OpenSuse
+    addNativeSourcesManager(QStringLiteral("YaST2/sw_source.desktop"));
 }
 
 QString PackageKitSourcesBackend::idDescription()
@@ -119,6 +107,15 @@ void PackageKitSourcesBackend::addRepositoryDetails(const QString &id, const QSt
 
     if (!item) {
         item = new QStandardItem(description);
+        if (PackageKit::Daemon::backendName() == QLatin1String("aptcc")) {
+            QRegularExpression exp(QStringLiteral("^/etc/apt/sources.list.d/(.+?).list:.*"));
+
+            auto matchIt = exp.globalMatch(id);
+            if (matchIt.hasNext()) {
+                auto match = matchIt.next();
+                item->setData(match.captured(1), Qt::ToolTipRole);
+            }
+        }
         add = true;
     }
     item->setData(id, IdRole);
@@ -145,13 +142,14 @@ bool PackageKitSourcesBackend::removeSource(const QString& id)
     return false;
 }
 
-QList<QAction *> PackageKitSourcesBackend::actions() const
+QVariantList PackageKitSourcesBackend::actions() const
 {
     return m_actions;
 }
 
 void PackageKitSourcesBackend::resetSources()
 {
+    disconnect(SourcesModel::global(), &SourcesModel::showingNow, this, &PackageKitSourcesBackend::resetSources);
     m_sources->clear();
     auto transaction = PackageKit::Daemon::global()->getRepoList();
     connect(transaction, &PackageKit::Transaction::repoDetail, this, &PackageKitSourcesBackend::addRepositoryDetails);
