@@ -1,22 +1,8 @@
-/***************************************************************************
- *   Copyright ?? 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 #ifndef RESOURCESMODEL_H
 #define RESOURCESMODEL_H
@@ -43,7 +29,8 @@ Q_SIGNALS:
 private:
     void addResults(const QVector<AbstractResource*>& res);
     void emitResults();
-    void destruction(QObject* obj);
+    void streamDestruction(QObject* obj);
+    void resourceDestruction(QObject* obj);
     void clear();
 
     QSet<QObject*> m_streams;
@@ -51,6 +38,29 @@ private:
     QTimer m_delayedEmission;
 };
 
+template <typename T>
+class EmitWhenChanged
+{
+public:
+    EmitWhenChanged(T initial, const std::function<T()> &get, const std::function<void(T)> &emitChanged)
+        : m_get(get)
+        , m_emitChanged(emitChanged)
+        , m_value(initial)
+    {}
+
+    void reevaluate() {
+        auto newValue = m_get();
+        if (newValue != m_value) {
+            m_value = newValue;
+            m_emitChanged(m_value);
+        }
+    }
+
+    std::function<T()> const m_get;
+    std::function<void(T)> const m_emitChanged;
+    T m_value;
+};
+
 class DISCOVERCOMMON_EXPORT ResourcesModel : public QObject
 {
     Q_OBJECT
@@ -60,6 +70,8 @@ class DISCOVERCOMMON_EXPORT ResourcesModel : public QObject
     Q_PROPERTY(QVariantList applicationBackends READ applicationBackendsVariant NOTIFY backendsChanged)
     Q_PROPERTY(AbstractResourcesBackend* currentApplicationBackend READ currentApplicationBackend WRITE setCurrentApplicationBackend NOTIFY currentApplicationBackendChanged)
     Q_PROPERTY(QAction* updateAction READ updateAction CONSTANT)
+    Q_PROPERTY(int fetchingUpdatesProgress READ fetchingUpdatesProgress NOTIFY fetchingUpdatesProgressChanged)
+    Q_PROPERTY(QString applicationSourceName READ applicationSourceName NOTIFY currentApplicationBackendChanged)
     public:
         /** This constructor should be only used by unit tests.
          *  @p backendName defines what backend will be loaded when the backend is constructed.
@@ -69,7 +81,7 @@ class DISCOVERCOMMON_EXPORT ResourcesModel : public QObject
         ~ResourcesModel() override;
         
         QVector< AbstractResourcesBackend* > backends() const;
-        int updatesCount() const;
+        int updatesCount() const { return m_updatesCount.m_value; }
         bool hasSecurityUpdates() const;
         
         bool isBusy() const;
@@ -78,15 +90,17 @@ class DISCOVERCOMMON_EXPORT ResourcesModel : public QObject
         Q_SCRIPTABLE bool isExtended(const QString &id);
 
         AggregatedResultsStream* search(const AbstractResourcesBackend::Filters &search);
-        AbstractResource* resourceForFile(const QUrl &/*url*/);
         void checkForUpdates();
 
+        QString applicationSourceName() const;
+
         QVariantList applicationBackendsVariant() const;
         QVector<AbstractResourcesBackend*> applicationBackends() const;
         void setCurrentApplicationBackend(AbstractResourcesBackend* backend, bool writeConfig = true);
         AbstractResourcesBackend* currentApplicationBackend() const;
 
         QAction* updateAction() const { return m_updateAction; }
+        int fetchingUpdatesProgress() const { return m_fetchingUpdatesProgress.m_value; }
 
     public Q_SLOTS:
         void installApplication(AbstractResource* app, const AddonList& addons);
@@ -97,12 +111,13 @@ class DISCOVERCOMMON_EXPORT ResourcesModel : public QObject
         void fetchingChanged(bool isFetching);
         void allInitialized();
         void backendsChanged();
-        void updatesCountChanged();
+        void updatesCountChanged(int updatesCount);
         void backendDataChanged(AbstractResourcesBackend* backend, const QVector<QByteArray>& properties);
         void resourceDataChanged(AbstractResource* resource, const QVector<QByteArray>& properties);
         void resourceRemoved(AbstractResource* resource);
         void passiveMessage(const QString &message);
         void currentApplicationBackendChanged(AbstractResourcesBackend* currentApplicationBackend);
+        void fetchingUpdatesProgressChanged(int fetchingUpdatesProgress);
 
     private Q_SLOTS:
         void callerFetchingChanged();
@@ -123,6 +138,10 @@ class DISCOVERCOMMON_EXPORT ResourcesModel : public QObject
         int m_initializingBackends;
         QAction* m_updateAction = nullptr;
         AbstractResourcesBackend* m_currentApplicationBackend;
+        QTimer* m_allInitializedEmitter;
+
+        EmitWhenChanged<int> m_updatesCount;
+        EmitWhenChanged<int> m_fetchingUpdatesProgress;
 
         static ResourcesModel* s_self;
 };
