@@ -1,27 +1,13 @@
-/***************************************************************************
- *   Copyright © 2010 Jonathan Thomas <echidnaman@kubuntu.org>             *
- *   Copyright © 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2010 Jonathan Thomas <echidnaman@kubuntu.org>
+ *   SPDX-FileCopyrightText: 2012 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 #include "ResourcesProxyModel.h"
 
-#include <QDebug>
+#include "libdiscover_debug.h"
 #include <QMetaProperty>
 #include <utils.h>
 
@@ -52,23 +38,27 @@ ResourcesProxyModel::ResourcesProxyModel(QObject *parent)
         { DisplayOriginRole, "displayOrigin" },
         { CanUpgrade, "canUpgrade" },
         { PackageNameRole, "packageName" },
-        { IsTechnicalRole, "isTechnical" },
         { CategoryRole, "category" },
         { CategoryDisplayRole, "categoryDisplay" },
         { SectionRole, "section" },
         { MimeTypes, "mimetypes" },
         { LongDescriptionRole, "longDescription" },
-        { AvailableVersionRole, "availableVersion" },
-        { SizeRole, "size" }
+        { SourceIconRole, "sourceIcon" },
+        { SizeRole, "size" },
+        { ReleaseDateRole, "releaseDate" }
         })
     , m_currentStream(nullptr)
 {
-//     new ModelTest(this, this);
+//     new QAbstractItemModelTester(this, this);
 
     connect(ResourcesModel::global(), &ResourcesModel::backendsChanged, this, &ResourcesProxyModel::invalidateFilter);
     connect(ResourcesModel::global(), &ResourcesModel::backendDataChanged, this, &ResourcesProxyModel::refreshBackend);
     connect(ResourcesModel::global(), &ResourcesModel::resourceDataChanged, this, &ResourcesProxyModel::refreshResource);
     connect(ResourcesModel::global(), &ResourcesModel::resourceRemoved, this, &ResourcesProxyModel::removeResource);
+
+    connect(this, &QAbstractItemModel::modelReset, this, &ResourcesProxyModel::countChanged);
+    connect(this, &QAbstractItemModel::rowsInserted, this, &ResourcesProxyModel::countChanged);
+    connect(this, &QAbstractItemModel::rowsRemoved, this, &ResourcesProxyModel::countChanged);
 }
 
 void ResourcesProxyModel::componentComplete()
@@ -97,7 +87,7 @@ void ResourcesProxyModel::setSortOrder(Qt::SortOrder sortOrder)
 {
     if (sortOrder != m_sortOrder) {
         m_sortOrder = sortOrder;
-        Q_EMIT sortRoleChanged(sortOrder);
+        Q_EMIT sortOrderChanged(sortOrder);
         invalidateSorting();
     }
 }
@@ -111,7 +101,10 @@ void ResourcesProxyModel::setSearch(const QString &_searchText)
 
     if (diff) {
         m_filters.search = searchText;
-        m_sortByRelevancy = !searchText.isEmpty();
+        if (m_sortByRelevancy == searchText.isEmpty()) {
+            m_sortByRelevancy = !searchText.isEmpty();
+            Q_EMIT sortByRelevancyChanged(m_sortByRelevancy);
+        }
         invalidateFilter();
         Q_EMIT searchChanged(m_filters.search);
     }
@@ -120,6 +113,7 @@ void ResourcesProxyModel::setSearch(const QString &_searchText)
 void ResourcesProxyModel::removeDuplicates(QVector<AbstractResource *>& resources)
 {
     const auto cab = ResourcesModel::global()->currentApplicationBackend();
+    QHash<QString, QString> aliases;
     QHash<QString, QVector<AbstractResource *>::iterator> storedIds;
     for(auto it = m_displayedResources.begin(); it != m_displayedResources.end(); ++it)
     {
@@ -131,9 +125,14 @@ void ResourcesProxyModel::removeDuplicates(QVector<AbstractResource *>& resource
         if (at == storedIds.end()) {
             storedIds[appstreamid] = it;
         } else {
-            qWarning() << "We should have sanitized the displayed resources. There is a bug";
+            qCWarning(LIBDISCOVER_LOG) << "We should have sanitized the displayed resources. There is a bug";
             Q_UNREACHABLE();
         }
+
+        const auto alts = (*it)->alternativeAppstreamIds();
+        for (const auto &alias : alts) {
+            aliases[alias] = appstreamid;
+        }
     }
 
     QHash<QString, QVector<AbstractResource *>::iterator> ids;
@@ -145,10 +144,57 @@ void ResourcesProxyModel::removeDuplicates(QVector<AbstractResource *>& resource
             continue;
         }
         auto at = storedIds.find(appstreamid);
+        if (at == storedIds.end()) {
+            auto aliased = aliases.constFind(appstreamid);
+            if (aliased != aliases.constEnd()) {
+                at = storedIds.find(aliased.value());
+            }
+        }
+
+        if (at == storedIds.end()) {
+            const auto alts = (*it)->alternativeAppstreamIds();
+            for (const auto &alt : alts) {
+                at = storedIds.find(alt);
+                if (at == storedIds.end())
+                    break;
+
+                auto aliased = aliases.constFind(alt);
+                if (aliased != aliases.constEnd()) {
+                    at = storedIds.find(aliased.value());
+                    if (at != storedIds.end())
+                        break;
+                }
+            }
+        }
         if (at == storedIds.end()) {
             auto at = ids.find(appstreamid);
+            if (at == ids.end()) {
+                auto aliased = aliases.constFind(appstreamid);
+                if (aliased != aliases.constEnd()) {
+                    at = ids.find(aliased.value());
+                }
+            }
+            if (at == ids.end()) {
+                const auto alts = (*it)->alternativeAppstreamIds();
+                for (const auto &alt : alts) {
+                    at = ids.find(alt);
+                    if (at != ids.end())
+                        break;
+
+                    auto aliased = aliases.constFind(appstreamid);
+                    if (aliased != aliases.constEnd()) {
+                        at = ids.find(aliased.value());
+                        if (at != ids.end())
+                            break;
+                    }
+                }
+            }
             if (at == ids.end()) {
                 ids[appstreamid] = it;
+                const auto alts = (*it)->alternativeAppstreamIds();
+                for (const auto &alias : alts) {
+                    aliases[alias] = appstreamid;
+                }
                 ++it;
             } else {
                 if ((*it)->backend() == cab) {
@@ -160,7 +206,7 @@ void ResourcesProxyModel::removeDuplicates(QVector<AbstractResource *>& resource
             if ((*it)->backend() == cab) {
                 **at = *it;
                 auto pos = index(*at - m_displayedResources.begin(), 0);
-                dataChanged(pos, pos);
+                Q_EMIT dataChanged(pos, pos);
             }
             it = resources.erase(it);
         }
@@ -176,7 +222,7 @@ void ResourcesProxyModel::addResources(const QVector<AbstractResource *>& _res)
         return;
 
     if (!m_sortByRelevancy)
-        qSort(res.begin(), res.end(), [this](AbstractResource* res, AbstractResource* res2){ return lessThan(res, res2); });
+        std::sort(res.begin(), res.end(), [this](AbstractResource* res, AbstractResource* res2){ return lessThan(res, res2); });
 
     sortedInsertion(res);
     fetchSubcategories();
@@ -189,7 +235,7 @@ void ResourcesProxyModel::invalidateSorting()
 
     if (!m_sortByRelevancy) {
         beginResetModel();
-        qSort(m_displayedResources.begin(), m_displayedResources.end(), [this](AbstractResource* res, AbstractResource* res2){ return lessThan(res, res2); });
+        std::sort(m_displayedResources.begin(), m_displayedResources.end(), [this](AbstractResource* res, AbstractResource* res2){ return lessThan(res, res2); });
         endResetModel();
     }
 }
@@ -226,13 +272,13 @@ void ResourcesProxyModel::setFiltersFromCategory(Category *category)
 
 void ResourcesProxyModel::fetchSubcategories()
 {
-    auto cats = (m_filters.category ? m_filters.category->subCategories() : CategoryModel::global()->rootCategories()).toList().toSet();
+    auto cats = kToSet(m_filters.category ? m_filters.category->subCategories() : CategoryModel::global()->rootCategories());
 
     const int count = rowCount();
     QSet<Category*> done;
     for (int i=0; i<count && !cats.isEmpty(); ++i) {
         AbstractResource* res = m_displayedResources[i];
-        const auto found = res->categoryObjects(cats.toList().toVector());
+        const auto found = res->categoryObjects(kSetToVector(cats));
         done.unite(found);
         cats.subtract(found);
     }
@@ -256,7 +302,7 @@ void ResourcesProxyModel::invalidateFilter()
     }
 
     if (m_currentStream) {
-        qWarning() << "last stream isn't over yet" << m_filters << this;
+        qCWarning(LIBDISCOVER_LOG) << "last stream isn't over yet" << m_filters << this;
         delete m_currentStream;
     }
 
@@ -354,6 +400,20 @@ void ResourcesProxyModel::setExtends(const QString& extends)
     }
 }
 
+void ResourcesProxyModel::setFilterMinimumState(bool filterMinimumState)
+{
+    if (filterMinimumState != m_filters.filterMinimumState) {
+        m_filters.filterMinimumState = filterMinimumState;
+        invalidateFilter();
+        Q_EMIT filterMinimumStateChanged(m_filters.filterMinimumState);
+    }
+}
+
+bool ResourcesProxyModel::filterMinimumState() const
+{
+    return m_filters.filterMinimumState;
+}
+
 QUrl ResourcesProxyModel::resourcesUrl() const
 {
     return m_filters.resourceUrl;
@@ -391,7 +451,7 @@ QVariant ResourcesProxyModel::roleToValue(AbstractResource* resource, int role)
 {
     switch(role) {
         case ApplicationRole:
-            return qVariantFromValue<QObject*>(resource);
+            return QVariant::fromValue<QObject*>(resource);
         case RatingPointsRole:
         case RatingRole:
         case RatingCountRole:
@@ -416,14 +476,14 @@ QVariant ResourcesProxyModel::roleToValue(AbstractResource* resource, int role)
         default: {
             QByteArray roleText = roleNames().value(role);
             if(Q_UNLIKELY(roleText.isEmpty())) {
-                qDebug() << "unsupported role" << role;
+                qCDebug(LIBDISCOVER_LOG) << "unsupported role" << role;
                 return {};
             }
             static const QMetaObject* m = &AbstractResource::staticMetaObject;
             int propidx = roleText.isEmpty() ? -1 : m->indexOfProperty(roleText.constData());
 
             if(Q_UNLIKELY(propidx < 0)) {
-                qWarning() << "unknown role:" << role << roleText;
+                qCWarning(LIBDISCOVER_LOG) << "unknown role:" << role << roleText;
                 return QVariant();
             } else
                 return m->property(propidx).read(resource);
@@ -463,7 +523,7 @@ void ResourcesProxyModel::sortedInsertion(const QVector<AbstractResource*> & _re
         return;
     }
 
-    for(auto resource: resources) {
+    for(auto resource: qAsConst(resources)) {
         const auto finder = [this](AbstractResource* resource, AbstractResource* res){ return lessThan(resource, res); };
         const auto it = std::upper_bound(m_displayedResources.constBegin(), m_displayedResources.constEnd(), resource, finder);
         const auto newIdx = it == m_displayedResources.constEnd() ? m_displayedResources.count() : (it - m_displayedResources.constBegin());
@@ -559,3 +619,22 @@ AbstractResource * ResourcesProxyModel::resourceAt(int row) const
 {
     return m_displayedResources[row];
 }
+
+bool ResourcesProxyModel::canFetchMore(const QModelIndex& parent) const
+{
+    Q_ASSERT(!parent.isValid());
+    return m_currentStream;
+}
+
+void ResourcesProxyModel::fetchMore(const QModelIndex& parent)
+{
+    Q_ASSERT(!parent.isValid());
+    if (!m_currentStream)
+        return;
+    Q_EMIT m_currentStream->fetchMore();
+}
+
+bool ResourcesProxyModel::sortByRelevancy() const
+{
+    return m_sortByRelevancy;
+}
